==> swi-prolog-6.2.6.tgz: lib/swipl-6.2.6/library/semweb/INDEX.pl <==
/*  Creator: make/0

    Purpose: Provide index for autoload
*/

index((rdf_set_cache_options), 1, rdf_cache, rdf_cache).
index((rdf_cache_file), 3, rdf_cache, rdf_cache).
index((rdf_equal_graphs), 3, rdf_compare, rdf_compare).
index((rdf_version), 1, rdf_db, rdf_db).
index((rdf), 3, rdf_db, rdf_db).
index((rdf), 4, rdf_db, rdf_db).
index((rdf_has), 3, rdf_db, rdf_db).
index((rdf_has), 4, rdf_db, rdf_db).
index((rdf_reachable), 3, rdf_db, rdf_db).
index((rdf_reachable), 5, rdf_db, rdf_db).
index((rdf_subject), 1, rdf_db, rdf_db).
index((rdf_member_property), 2, rdf_db, rdf_db).
index((rdf_assert), 3, rdf_db, rdf_db).
index((rdf_assert), 4, rdf_db, rdf_db).
index((rdf_retractall), 3, rdf_db, rdf_db).
index((rdf_retractall), 4, rdf_db, rdf_db).
index((rdf_update), 4, rdf_db, rdf_db).
index((rdf_update), 5, rdf_db, rdf_db).
index((rdf_set_predicate), 2, rdf_db, rdf_db).
index((rdf_predicate_property), 2, rdf_db, rdf_db).
index((rdf_current_predicate), 1, rdf_db, rdf_db).
index((rdf_current_literal), 1, rdf_db, rdf_db).
index((rdf_transaction), 1, rdf_db, rdf_db).
index((rdf_transaction), 2, rdf_db, rdf_db).
index((rdf_active_transaction), 1, rdf_db, rdf_db).
index((rdf_monitor), 2, rdf_db, rdf_db).
index((rdf_save_db), 1, rdf_db, rdf_db).
index((rdf_save_db), 2, rdf_db, rdf_db).
index((rdf_load_db), 1, rdf_db, rdf_db).
index((rdf_reset_db), 0, rdf_db, rdf_db).
index((rdf_node), 1, rdf_db, rdf_db).
index((rdf_bnode), 1, rdf_db, rdf_db).
index((rdf_is_bnode), 1, rdf_db, rdf_db).
index((rdf_is_resource), 1, rdf_db, rdf_db).
index((rdf_is_literal), 1, rdf_db, rdf_db).
index((rdf_load), 1, rdf_db, rdf_db).
index((rdf_load), 2, rdf_db, rdf_db).
index((rdf_save), 1, rdf_db, rdf_db).
index((rdf_save), 2, rdf_db, rdf_db).
index((rdf_unload), 1, rdf_db, rdf_db).
index((rdf_md5), 2, rdf_db, rdf_db).
index((rdf_atom_md5), 3, rdf_db, rdf_db).
index((rdf_graph_property), 2, rdf_db, rdf_db).
index((rdf_set_graph), 2, rdf_db, rdf_db).
index((rdf_graph), 1, rdf_db, rdf_db).
index((rdf_source), 1, rdf_db, rdf_db).
index((rdf_source), 2, rdf_db, rdf_db).
index((rdf_make), 0, rdf_db, rdf_db).
index((rdf_source_location), 2, rdf_db, rdf_db).
index((rdf_statistics), 1, rdf_db, rdf_db).
index((rdf_generation), 1, rdf_db, rdf_db).
index((rdf_estimate_complexity), 4, rdf_db, rdf_db).
index((rdf_save_subject), 3, rdf_db, rdf_db).
index((rdf_save_header), 2, rdf_db, rdf_db).
index((rdf_save_footer), 1, rdf_db, rdf_db).
index((rdf_equal), 2, rdf_db, rdf_db).
index((lang_equal), 2, rdf_db, rdf_db).
index((lang_matches), 2, rdf_db, rdf_db).
index((rdf_current_ns), 2, rdf_db, rdf_db).
index((rdf_register_ns), 2, rdf_db, rdf_db).
index((rdf_register_ns), 3, rdf_db, rdf_db).
index((rdf_current_prefix), 2, rdf_db, rdf_db).
index((rdf_register_prefix), 2, rdf_db, rdf_db).
index((rdf_register_prefix), 3, rdf_db, rdf_db).
index((rdf_global_id), 2, rdf_db, rdf_db).
index((rdf_global_object), 2, rdf_db, rdf_db).
index((rdf_global_term), 2, rdf_db, rdf_db).
index((rdf_match_label), 3, rdf_db, rdf_db).
index((rdf_split_url), 3, rdf_db, rdf_db).
index((rdf_url_namespace), 2, rdf_db, rdf_db).
index((rdf_quote_uri), 2, rdf_db, rdf_db).
index((rdf_debug), 1, rdf_db, rdf_db).
index((rdf_new_literal_map), 1, rdf_db, rdf_db).
index((rdf_destroy_literal_map), 1, rdf_db, rdf_db).
index((rdf_reset_literal_map), 1, rdf_db, rdf_db).
index((rdf_insert_literal_map), 3, rdf_db, rdf_db).
index((rdf_insert_literal_map), 4, rdf_db, rdf_db).
index((rdf_delete_literal_map), 3, rdf_db, rdf_db).
index((rdf_delete_literal_map), 2, rdf_db, rdf_db).
index((rdf_find_literal_map), 3, rdf_db, rdf_db).
index((rdf_keys_in_literal_map), 3, rdf_db, rdf_db).
index((rdf_statistics_literal_map), 2, rdf_db, rdf_db).
index((rdf_graph_prefixes), 2, rdf_db, rdf_db).
index((rdf_graph_prefixes), 3, rdf_db, rdf_db).
index((rdf_meta), 1, rdf_db, rdf_db).
index((rdfe_assert), 3, rdf_edit, rdf_edit).
index((rdfe_assert), 4, rdf_edit, rdf_edit).
index((rdfe_retractall), 3, rdf_edit, rdf_edit).
index((rdfe_retractall), 4, rdf_edit, rdf_edit).
index((rdfe_update), 4, rdf_edit, rdf_edit).
index((rdfe_update), 5, rdf_edit, rdf_edit).
index((rdfe_load), 1, rdf_edit, rdf_edit).
index((rdfe_load), 2, rdf_edit, rdf_edit).
index((rdfe_delete), 1, rdf_edit, rdf_edit).
index((rdfe_register_ns), 2, rdf_edit, rdf_edit).
index((rdfe_unregister_ns), 2, rdf_edit, rdf_edit).
index((rdfe_reset), 0, rdf_edit, rdf_edit).
index((rdfe_transaction), 1, rdf_edit, rdf_edit).
index((rdfe_transaction), 2, rdf_edit, rdf_edit).
index((rdfe_transaction_member), 2, rdf_edit, rdf_edit).
index((rdfe_transaction_name), 2, rdf_edit, rdf_edit).
index((rdfe_set_transaction_name), 1, rdf_edit, rdf_edit).
index((rdfe_set_watermark), 1, rdf_edit, rdf_edit).
index((rdfe_undo), 0, rdf_edit, rdf_edit).
index((rdfe_redo), 0, rdf_edit, rdf_edit).
index((rdfe_can_undo), 1, rdf_edit, rdf_edit).
index((rdfe_can_redo), 1, rdf_edit, rdf_edit).
index((rdfe_set_file_property), 2, rdf_edit, rdf_edit).
index((rdfe_get_file_property), 2, rdf_edit, rdf_edit).
index((rdfe_is_modified), 1, rdf_edit, rdf_edit).
index((rdfe_clear_modified), 1, rdf_edit, rdf_edit).
index((rdfe_open_journal), 2, rdf_edit, rdf_edit).
index((rdfe_close_journal), 0, rdf_edit, rdf_edit).
index((rdfe_replay_journal), 1, rdf_edit, rdf_edit).
index((rdfe_current_journal), 1, rdf_edit, rdf_edit).
index((rdfe_snapshot_file), 1, rdf_edit, rdf_edit).
index((rdf_attach_library), 1, rdf_library, rdf_library).
index((rdf_load_library), 1, rdf_library, rdf_library).
index((rdf_load_library), 2, rdf_library, rdf_library).
index((rdf_list_library), 0, rdf_library, rdf_library).
index((rdf_list_library), 1, rdf_library, rdf_library).
index((rdf_list_library), 2, rdf_library, rdf_library).
index((rdf_library_source), 2, rdf_library, rdf_library).
index((rdf_library_index), 2, rdf_library, rdf_library).
index((rdf_current_manifest), 1, rdf_library, rdf_library).
index((rdf_set_literal_index_option), 1, rdf_litindex, rdf_litindex).
index((rdf_tokenize_literal), 2, rdf_litindex, rdf_litindex).
index((rdf_find_literals), 2, rdf_litindex, rdf_litindex).
index((rdf_token_expansions), 2, rdf_litindex, rdf_litindex).
index((rdf_attach_db), 2, rdf_persistency, rdf_persistency).
index((rdf_detach_db), 0, rdf_persistency, rdf_persistency).
index((rdf_current_db), 1, rdf_persistency, rdf_persistency).
index((rdf_persistency), 2, rdf_persistency, rdf_persistency).
index((rdf_flush_journals), 1, rdf_persistency, rdf_persistency).
index((rdf_journal_file), 2, rdf_persistency, rdf_persistency).
index((rdf_db_to_file), 2, rdf_persistency, rdf_persistency).
index((rdf_portray_as), 1, rdf_portray, rdf_portray).
index((rdf_portray_lang), 1, rdf_portray, rdf_portray).
index((rdf_load_turtle), 3, rdf_turtle, rdf_turtle).
index((rdf_read_turtle), 3, rdf_turtle, rdf_turtle).
index((rdf_process_turtle), 3, rdf_turtle, rdf_turtle).
index((rdf_save_turtle), 2, rdf_turtle_write, rdf_turtle_write).
index((rdf_save_canonical_turtle), 2, rdf_turtle_write, rdf_turtle_write).
index((rdfs_subproperty_of), 2, rdfs, rdfs).
index((rdfs_subclass_of), 2, rdfs, rdfs).
index((rdfs_class_property), 2, rdfs, rdfs).
index((rdfs_individual_of), 2, rdfs, rdfs).
index((rdfs_label), 2, rdfs, rdfs).
index((rdfs_label), 3, rdfs, rdfs).
index((rdfs_ns_label), 2, rdfs, rdfs).
index((rdfs_ns_label), 3, rdfs, rdfs).
index((rdfs_member), 2, rdfs, rdfs).
index((rdfs_list_to_prolog_list), 2, rdfs, rdfs).
index((rdfs_assert_list), 3, rdfs, rdfs).
index((rdfs_assert_list), 2, rdfs, rdfs).
index((rdfs_find), 5, rdfs, rdfs).
index((sparql_query), 3, sparql_client, sparql_client).
index((sparql_set_server), 1, sparql_client, sparql_client).
index((sparql_read_xml_result), 2, sparql_client, sparql_client).
index((sparql_read_json_result), 2, sparql_client, sparql_client).
index((turtle_name_start_char), 1, turtle_base, turtle_base).
index((turtle_name), 1, turtle_base, turtle_base).
index((turtle_read_name), 4, turtle_base, turtle_base).
index((turtle_read_string), 4, turtle_base, turtle_base).
index((turtle_read_relative_uri), 4, turtle_base, turtle_base).
index((turtle_write_quoted_string), 2, turtle_base, turtle_base).
index((turtle_write_uri), 2, turtle_base, turtle_base).

==> swi-prolog-6.6.4p6.tgz: lib/swipl-6.6.4/library/semweb/INDEX.pl <==
/*  Creator: make/0

    Purpose: Provide index for autoload
*/

index((rdf_set_cache_options), 1, rdf_cache, rdf_cache).
index((rdf_cache_file), 3, rdf_cache, rdf_cache).
index((rdf_equal_graphs), 3, rdf_compare, rdf_compare).
index((rdf_version), 1, rdf_db, rdf_db).
index((rdf), 3, rdf_db, rdf_db).
index((rdf), 4, rdf_db, rdf_db).
index((rdf_has), 3, rdf_db, rdf_db).
index((rdf_has), 4, rdf_db, rdf_db).
index((rdf_reachable), 3, rdf_db, rdf_db).
index((rdf_reachable), 5, rdf_db, rdf_db).
index((rdf_resource), 1, rdf_db, rdf_db).
index((rdf_subject), 1, rdf_db, rdf_db).
index((rdf_member_property), 2, rdf_db, rdf_db).
index((rdf_assert), 3, rdf_db, rdf_db).
index((rdf_assert), 4, rdf_db, rdf_db).
index((rdf_retractall), 3, rdf_db, rdf_db).
index((rdf_retractall), 4, rdf_db, rdf_db).
index((rdf_update), 4, rdf_db, rdf_db).
index((rdf_update), 5, rdf_db, rdf_db).
index((rdf_set_predicate), 2, rdf_db, rdf_db).
index((rdf_predicate_property), 2, rdf_db, rdf_db).
index((rdf_current_predicate), 1, rdf_db, rdf_db).
index((rdf_current_literal), 1, rdf_db, rdf_db).
index((rdf_transaction), 1, rdf_db, rdf_db).
index((rdf_transaction), 2, rdf_db, rdf_db).
index((rdf_transaction), 3, rdf_db, rdf_db).
index((rdf_active_transaction), 1, rdf_db, rdf_db).
index((rdf_monitor), 2, rdf_db, rdf_db).
index((rdf_save_db), 1, rdf_db, rdf_db).
index((rdf_save_db), 2, rdf_db, rdf_db).
index((rdf_load_db), 1, rdf_db, rdf_db).
index((rdf_reset_db), 0, rdf_db, rdf_db).
index((rdf_node), 1, rdf_db, rdf_db).
index((rdf_bnode), 1, rdf_db, rdf_db).
index((rdf_is_bnode), 1, rdf_db, rdf_db).
index((rdf_is_resource), 1, rdf_db, rdf_db).
index((rdf_is_literal), 1, rdf_db, rdf_db).
index((rdf_literal_value), 2, rdf_db, rdf_db).
index((rdf_load), 1, rdf_db, rdf_db).
index((rdf_load), 2, rdf_db, rdf_db).
index((rdf_save), 1, rdf_db, rdf_db).
index((rdf_save), 2, rdf_db, rdf_db).
index((rdf_unload), 1, rdf_db, rdf_db).
index((rdf_unload_graph), 1, rdf_db, rdf_db).
index((rdf_md5), 2, rdf_db, rdf_db).
index((rdf_atom_md5), 3, rdf_db, rdf_db).
index((rdf_create_graph), 1, rdf_db, rdf_db).
index((rdf_graph_property), 2, rdf_db, rdf_db).
index((rdf_set_graph), 2, rdf_db, rdf_db).
index((rdf_graph), 1, rdf_db, rdf_db).
index((rdf_source), 1, rdf_db, rdf_db).
index((rdf_source), 2, rdf_db, rdf_db).
index((rdf_make), 0, rdf_db, rdf_db).
index((rdf_gc), 0, rdf_db, rdf_db).
index((rdf_source_location), 2, rdf_db, rdf_db).
index((rdf_statistics), 1, rdf_db, rdf_db).
index((rdf_set), 1, rdf_db, rdf_db).
index((rdf_generation), 1, rdf_db, rdf_db).
index((rdf_snapshot), 1, rdf_db, rdf_db).
index((rdf_delete_snapshot), 1, rdf_db, rdf_db).
index((rdf_current_snapshot), 1, rdf_db, rdf_db).
index((rdf_estimate_complexity), 4, rdf_db, rdf_db).
index((rdf_save_subject), 3, rdf_db, rdf_db).
index((rdf_save_header), 2, rdf_db, rdf_db).
index((rdf_save_footer), 1, rdf_db, rdf_db).
index((rdf_equal), 2, rdf_db, rdf_db).
index((lang_equal), 2, rdf_db, rdf_db).
index((lang_matches), 2, rdf_db, rdf_db).
index((rdf_current_prefix), 2, rdf_db, rdf_db).
index((rdf_register_prefix), 2, rdf_db, rdf_db).
index((rdf_register_prefix), 3, rdf_db, rdf_db).
index((rdf_current_ns), 2, rdf_db, rdf_db).
index((rdf_register_ns), 2, rdf_db, rdf_db).
index((rdf_register_ns), 3, rdf_db, rdf_db).
index((rdf_global_id), 2, rdf_db, rdf_db).
index((rdf_global_object), 2, rdf_db, rdf_db).
index((rdf_global_term), 2, rdf_db, rdf_db).
index((rdf_match_label), 3, rdf_db, rdf_db).
index((rdf_split_url), 3, rdf_db, rdf_db).
index((rdf_url_namespace), 2, rdf_db, rdf_db).
index((rdf_warm_indexes), 0, rdf_db, rdf_db).
index((rdf_warm_indexes), 1, rdf_db, rdf_db).
index((rdf_update_duplicates), 0, rdf_db, rdf_db).
index((rdf_debug), 1, rdf_db, rdf_db).
index((rdf_new_literal_map), 1, rdf_db, rdf_db).
index((rdf_destroy_literal_map), 1, rdf_db, rdf_db).
index((rdf_reset_literal_map), 1, rdf_db, rdf_db).
index((rdf_insert_literal_map), 3, rdf_db, rdf_db).
index((rdf_insert_literal_map), 4, rdf_db, rdf_db).
index((rdf_delete_literal_map), 3, rdf_db, rdf_db).
index((rdf_delete_literal_map), 2, rdf_db, rdf_db).
index((rdf_find_literal_map), 3, rdf_db, rdf_db).
index((rdf_keys_in_literal_map), 3, rdf_db, rdf_db).
index((rdf_statistics_literal_map), 2, rdf_db, rdf_db).
index((rdf_graph_prefixes), 2, rdf_db, rdf_db).
index((rdf_graph_prefixes), 3, rdf_db, rdf_db).
index((rdf_meta), 1, rdf_db, rdf_db).
index((rdfe_assert), 3, rdf_edit, rdf_edit).
index((rdfe_assert), 4, rdf_edit, rdf_edit).
index((rdfe_retractall), 3, rdf_edit, rdf_edit).
index((rdfe_retractall), 4, rdf_edit, rdf_edit).
index((rdfe_update), 4, rdf_edit, rdf_edit).
index((rdfe_update), 5, rdf_edit, rdf_edit).
index((rdfe_load), 1, rdf_edit, rdf_edit).
index((rdfe_load), 2, rdf_edit, rdf_edit).
index((rdfe_delete), 1, rdf_edit, rdf_edit).
index((rdfe_register_ns), 2, rdf_edit, rdf_edit).
index((rdfe_unregister_ns), 2, rdf_edit, rdf_edit).
index((rdfe_reset), 0, rdf_edit, rdf_edit).
index((rdfe_transaction), 1, rdf_edit, rdf_edit).
index((rdfe_transaction), 2, rdf_edit, rdf_edit).
index((rdfe_transaction_member), 2, rdf_edit, rdf_edit).
index((rdfe_transaction_name), 2, rdf_edit, rdf_edit).
index((rdfe_set_transaction_name), 1, rdf_edit, rdf_edit).
index((rdfe_set_watermark), 1, rdf_edit, rdf_edit).
index((rdfe_undo), 0, rdf_edit, rdf_edit).
index((rdfe_redo), 0, rdf_edit, rdf_edit).
index((rdfe_can_undo), 1, rdf_edit, rdf_edit).
index((rdfe_can_redo), 1, rdf_edit, rdf_edit).
index((rdfe_set_file_property), 2, rdf_edit, rdf_edit).
index((rdfe_get_file_property), 2, rdf_edit, rdf_edit).
index((rdfe_is_modified), 1, rdf_edit, rdf_edit).
index((rdfe_clear_modified), 1, rdf_edit, rdf_edit).
index((rdfe_open_journal), 2, rdf_edit, rdf_edit).
index((rdfe_close_journal), 0, rdf_edit, rdf_edit).
index((rdfe_replay_journal), 1, rdf_edit, rdf_edit).
index((rdfe_current_journal), 1, rdf_edit, rdf_edit).
index((rdfe_snapshot_file), 1, rdf_edit, rdf_edit).
index((rdf_attach_library), 1, rdf_library, rdf_library).
index((rdf_load_library), 1, rdf_library, rdf_library).
index((rdf_load_library), 2, rdf_library, rdf_library).
index((rdf_list_library), 0, rdf_library, rdf_library).
index((rdf_list_library), 1, rdf_library, rdf_library).
index((rdf_list_library), 2, rdf_library, rdf_library).
index((rdf_library_source), 2, rdf_library, rdf_library).
index((rdf_library_index), 2, rdf_library, rdf_library).
index((rdf_current_manifest), 1, rdf_library, rdf_library).
index((rdf_set_literal_index_option), 1, rdf_litindex, rdf_litindex).
index((rdf_tokenize_literal), 2, rdf_litindex, rdf_litindex).
index((rdf_find_literals), 2, rdf_litindex, rdf_litindex).
index((rdf_token_expansions), 2, rdf_litindex, rdf_litindex).
index((rdf_read_ntriples), 3, rdf_ntriples, rdf_ntriples).
index((rdf_read_nquads), 3, rdf_ntriples, rdf_ntriples).
index((rdf_process_ntriples), 3, rdf_ntriples, rdf_ntriples).
index((read_ntriple), 2, rdf_ntriples, rdf_ntriples).
index((read_nquad), 2, rdf_ntriples, rdf_ntriples).
index((read_ntuple), 2, rdf_ntriples, rdf_ntriples).
index((rdf_attach_db), 2, rdf_persistency, rdf_persistency).
index((rdf_detach_db), 0, rdf_persistency, rdf_persistency).
index((rdf_current_db), 1, rdf_persistency, rdf_persistency).
index((rdf_persistency), 2, rdf_persistency, rdf_persistency).
index((rdf_flush_journals), 1, rdf_persistency, rdf_persistency).
index((rdf_journal_file), 2, rdf_persistency, rdf_persistency).
index((rdf_snapshot_file), 2, rdf_persistency, rdf_persistency).
index((rdf_db_to_file), 2, rdf_persistency, rdf_persistency).
index((rdf_portray_as), 1, rdf_portray, rdf_portray).
index((rdf_portray_lang), 1, rdf_portray, rdf_portray).
index((rdf_load_turtle), 3, rdf_turtle, rdf_turtle).
index((rdf_read_turtle), 3, rdf_turtle, rdf_turtle).
index((rdf_process_turtle), 3, rdf_turtle, rdf_turtle).
index((rdf_save_turtle), 2, rdf_turtle_write, rdf_turtle_write).
index((rdf_save_canonical_turtle), 2, rdf_turtle_write, rdf_turtle_write).
index((rdf_save_trig), 2, rdf_turtle_write, rdf_turtle_write).
index((rdf_save_canonical_trig), 2, rdf_turtle_write, rdf_turtle_write).
index((rdfs_subproperty_of), 2, rdfs, rdfs).
index((rdfs_subclass_of), 2, rdfs, rdfs).
index((rdfs_class_property), 2, rdfs, rdfs).
index((rdfs_individual_of), 2, rdfs, rdfs).
index((rdfs_label), 2, rdfs, rdfs).
index((rdfs_label), 3, rdfs, rdfs).
index((rdfs_ns_label), 2, rdfs, rdfs).
index((rdfs_ns_label), 3, rdfs, rdfs).
index((rdfs_member), 2, rdfs, rdfs).
index((rdfs_list_to_prolog_list), 2, rdfs, rdfs).
index((rdfs_assert_list), 3, rdfs, rdfs).
index((rdfs_assert_list), 2, rdfs, rdfs).
index((rdfs_find), 5, rdfs, rdfs).
index((sparql_query), 3, sparql_client, sparql_client).
index((sparql_set_server), 1, sparql_client, sparql_client).
index((sparql_read_xml_result), 2, sparql_client, sparql_client).
index((sparql_read_json_result), 2, sparql_client, sparql_client).
index((rdf_load_turtle), 3, turtle, turtle).
index((rdf_read_turtle), 3, turtle, turtle).
index((rdf_process_turtle), 3, turtle, turtle).
index((rdf_save_turtle), 2, turtle, turtle).
index((rdf_save_canonical_turtle), 2, turtle, turtle).
